/************************************************************************************************

 Author        : ADI - Apps            www.analog.com/AduC7060

 Date          : November 2007

 File          : DAC.c

 Hardware      : ADuC706x

 Description   : This Simple DAC example program shows how to initialize the DAC and output a 
 			Sine wave to it. The DAC is updated in a simple loop program where values are read from
			a table and sequentially outputted to the DAC
*************************************************************************************************/
// Bit Definitions
#define BIT0  0x01
#define BIT1  0x02
#define BIT2  0x04
#define BIT3  0x08
#define BIT4  0x10
#define BIT5  0x20
#define BIT6  0x40
#define BIT7  0x80
#define BIT8  0x100
#define BIT9  0x200
#define BIT10 0x400
#define BIT11 0x800
#define BIT12 0x1000
#define BIT13 0x2000
#define BIT14 0x4000
#define BIT15 0x8000


#include<aduc7060.h>
// Table is placed in Flash/EE
const static unsigned short TableS[64] = {
 	0x07FF, 0x08C8, 0x098E, 0x0A51, 0x0B0F, 0x0BC4, 0x0C71, 0x0D12,
 	0x0DA7, 0x0E2E, 0x0EA5, 0x0F0D, 0x0F63, 0x0FA6, 0x0FD7, 0x0FF5,
 	0x0FFF, 0x0FF5, 0x0FD7, 0x0FA6, 0x0F63, 0x0F0D, 0x0EA5, 0x0E2E,
 	0x0DA7, 0x0D12, 0x0C71, 0x0BC4, 0x0B0F, 0x0A51, 0x098E, 0x08C8,
 	0x07FF, 0x0736, 0x0670, 0x05AD, 0x04EF, 0x043A, 0x038D, 0x02EC,
 	0x0257, 0x01D0, 0x0159, 0x00F1, 0x009B, 0x0058, 0x0027, 0x0009,
 	0x0000, 0x0009, 0x0027, 0x0058, 0x009B, 0x00F1, 0x0159, 0x01D0,
 	0x0257, 0x02EC, 0x038D, 0x043A, 0x04EF, 0x05AD, 0x0670, 0x0736  
	};

int main(void)
{
    unsigned char i = 0;
	
	POWKEY1 = 0x1;
	POWCON0 = 0x78;		   // Set core to max CPU speed of 10.24Mhz
	POWKEY2 = 0xF4;
	
	// DAC configuration
	DACCON = BIT0 + BIT1 + 			// range AVdd/AGND
			 BIT4;					// Disable clearing of DACDAT + DAC is updated with falling edge of core clock

	DACDAT = ((0x0800)<< 16);		// start from midscale
 	DACDAT = 0x800000;
 	while(1)
	{
		// Sequentially output Table values to the DAC. The Table holds values representing
		// DAC Zero scale to full-scale in 64 steps.
		DACDAT = (TableS[i] << 16); 
		i++;
		i &= 0x03f;         	
	}
	return (0);
}




